@@ -582,9 +582,7 @@ impl Legacy {
                                     },
                                 }))
                             } else {
-                                undefined(DUMMY_SP)
-                                // Box::new(Expr::Lit(Lit::Null(Null { span:
-                                // DUMMY_SP })))
+                                Box::new(Expr::Lit(Lit::Null(Null { span: DUMMY_SP })))
                             },
                         }))),
                     ],
@@ -675,7 +673,7 @@ impl Legacy {
                     extra_exprs.push(call_expr);
                 }
 
-                if !p.is_static {
+                if !p.is_static && !p.declare {
                     constructor_stmts.push(
                         CallExpr {
                             span: DUMMY_SP,
